@@ -8,4 +8,9 @@ class ImageNotFound(Exception):
 class ReleaseNotFound(Exception):
     """
     Raised when the latest Release could not be identified.
-    """
\ No newline at end of file
+    """
+
+class ServiceUnavailable(Exception):
+    """
+    Raised when the Ubuntu Cloud Images service is not available
+    """
